##################################### TERMS OF USE ###########################################
# The following code is provided for demonstration purpose only, and should not be used      #
# without independent verification. Recorded Future makes no representations or warranties,  #
# express, implied, statutory, or otherwise, regarding any aspect of this code or of the     #
# information it may retrieve, and provides it both strictly “as-is” and without assuming    #
# responsibility for any information it may retrieve. Recorded Future shall not be liable    #
# for, and you assume all risk of using, the foregoing. By using this code, Customer         #
# represents that it is solely responsible for having all necessary licenses, permissions,   #
# rights, and/or consents to connect to third party APIs, and that it is solely responsible  #
# for having all necessary licenses, permissions, rights, and/or consents to any data        #
# accessed from any third party API.                                                         #
##############################################################################################

import functools
import logging


def debug_call(func):
    """Print debug logs for public methods."""
    logger = logging.getLogger(__name__)

    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        args_str = ', '.join(map(lambda x: str(x).strip('<psengine.')[:50], args))
        kwargs_str = ', '.join(f'{k}={str(v)[:50]!r}' for k, v in kwargs.items())
        sep = ', ' if args and kwargs else ''

        msg = f'Called {func.__name__}({args_str + sep + kwargs_str if args or kwargs else ""})'

        logger.debug(msg)
        ret_val = func(*args, **kwargs)

        msg = f'{func.__name__} ended with return value {str(ret_val)[:50]!r}'
        logger.debug(msg)

        return ret_val

    return wrapper
