##################################### TERMS OF USE ###########################################
# The following code is provided for demonstration purpose only, and should not be used      #
# without independent verification. Recorded Future makes no representations or warranties,  #
# express, implied, statutory, or otherwise, regarding any aspect of this code or of the     #
# information it may retrieve, and provides it both strictly “as-is” and without assuming    #
# responsibility for any information it may retrieve. Recorded Future shall not be liable    #
# for, and you assume all risk of using, the foregoing. By using this code, Customer         #
# represents that it is solely responsible for having all necessary licenses, permissions,   #
# rights, and/or consents to connect to third party APIs, and that it is solely responsible  #
# for having all necessary licenses, permissions, rights, and/or consents to any data        #
# accessed from any third party API.                                                         #
##############################################################################################

from typing import Union

from ..exceptions import RecordedFutureException


class PlaybookAlertError(RecordedFutureException):
    """Error raised when playbook alert fails."""

    def __init__(self, err: Union[str, Exception], message: str = 'Playbook alert failed'):
        RecordedFutureException.__init__(self, message, err)


class PlaybookAlertSearchError(PlaybookAlertError):
    """Error raised when playbook alert search query fails."""

    def __init__(self, message: str = 'Playbook alert search query failed', *args):
        RecordedFutureException.__init__(self, message % (args))


class PlaybookAlertUpdateError(PlaybookAlertError):
    """Error raised when playbook alert update fails."""

    def __init__(self, err: Union[str, Exception], message: str = 'Playbook alert update failed'):
        RecordedFutureException.__init__(self, message, err)


class PlaybookAlertFetchError(PlaybookAlertError):
    """Error raised when playbook alert fetch fails."""

    def __init__(self, err: Union[str, Exception], message: str = 'Playbook alert fetch failed'):
        RecordedFutureException.__init__(self, message, err)


class PlaybookAlertRetrieveImageError(PlaybookAlertError):
    """Error raised when playbook alert image fetch fails."""

    def __init__(
        self,
        err: Union[str, Exception],
        message: str = 'Playbook alert image fetch failed',
    ):
        RecordedFutureException.__init__(self, message, err)
