##################################### TERMS OF USE ###########################################
# The following code is provided for demonstration purpose only, and should not be used      #
# without independent verification. Recorded Future makes no representations or warranties,  #
# express, implied, statutory, or otherwise, regarding any aspect of this code or of the     #
# information it may retrieve, and provides it both strictly “as-is” and without assuming    #
# responsibility for any information it may retrieve. Recorded Future shall not be liable    #
# for, and you assume all risk of using, the foregoing. By using this code, Customer         #
# represents that it is solely responsible for having all necessary licenses, permissions,   #
# rights, and/or consents to connect to third party APIs, and that it is solely responsible  #
# for having all necessary licenses, permissions, rights, and/or consents to any data        #
# accessed from any third party API.                                                         #
##############################################################################################

import warnings
from typing import Union

from psengine.playbook_alerts.constants import DEPRECATION_MSG

from .rf_base_playbook_alert import RFBasePlaybookAlert


class RFPlaybookAlertCodeRepoLeakage(RFBasePlaybookAlert):
    """Playbook Alert for Code Repo Leakage."""

    @property
    def repository_name(self) -> Union[str, None]:
        """Code Repo Leak: Return repository URL.

        Returns:
            Union[str, None]: url of repo or None
        """
        return self.panel_evidence_summary.get('repository', {}).get('name', None)

    @property
    def repository_owner(self) -> Union[str, None]:
        """Code Repo Leak: Return repository owner name.

        Returns:
            Union[str, None]: owner of repo or None
        """
        return self.panel_evidence_summary.get('repository', {}).get('owner', {}).get('name', None)

    @property
    def evidence(self) -> list:
        """Code Repo Leak: Return the evidence block."""
        return self.panel_evidence_summary.get('evidence', [])

    @property
    def log_v2_code_repo_leakage_evidence_changes(self) -> list:
        """Code Repo Leakage Evidence change"""
        return [changes for changes in self.log_v2_changes if changes['type'] == 'evidence_change']

    @property
    def log_code_repo_leakage_changes(self) -> list:
        """Code Repo Leakage: Filter for log panels with context type code_repo_leakage.

        Returns:
            list: log panel changes with context type code_repo_leakage, or [] if not found
        """
        warnings.warn(DEPRECATION_MSG, DeprecationWarning)
        return list(
            filter(
                lambda log: log.get('context', {}).get('type') == 'code_repo_leakage',
                self.log_context_changes,
            ),
        )

    @property
    def log_evidence_changes(self) -> list:
        """Code Repo Leakage: Filter for log panels for evidence_changes only.

        Returns:
            list: log panel changes with context type code_repo_leakage containing only
                  evidence_changes, or [] if not found
        """
        warnings.warn(DEPRECATION_MSG, DeprecationWarning)
        return self._get_specific_context_changes('code_repo_leakage', 'evidence_change')
