##################################### TERMS OF USE ###########################################
# The following code is provided for demonstration purpose only, and should not be used      #
# without independent verification. Recorded Future makes no representations or warranties,  #
# express, implied, statutory, or otherwise, regarding any aspect of this code or of the     #
# information it may retrieve, and provides it both strictly “as-is” and without assuming    #
# responsibility for any information it may retrieve. Recorded Future shall not be liable    #
# for, and you assume all risk of using, the foregoing. By using this code, Customer         #
# represents that it is solely responsible for having all necessary licenses, permissions,   #
# rights, and/or consents to connect to third party APIs, and that it is solely responsible  #
# for having all necessary licenses, permissions, rights, and/or consents to any data        #
# accessed from any third party API.                                                         #
##############################################################################################
import warnings

from psengine.playbook_alerts.constants import DEPRECATION_MSG

from .rf_base_playbook_alert import RFBasePlaybookAlert


class RFPlaybookAlertThirdPartyRisk(RFBasePlaybookAlert):
    """Playbook Alert for Third Party Risk."""

    @property
    def assessments(self) -> list:
        """Third Party Risk: Return the assessments block.

        Each assessment contains:
            - risk_rule
            - level
            - added
            - evidence {}
                - type
                - summary
                - data []

        Returns:
            list[dict]: List of assessments
        """
        return self.panel_evidence_summary.get('assessments', [])

    @property
    def log_v2_third_party_assessment_change(self) -> list:
        """Third Party Assessment change"""
        return [
            changes for changes in self.log_v2_changes if changes['type'] == 'assessment_change'
        ]

    @property
    def log_third_party_risk_changes(self) -> list:
        """Third Party Risk: Filter for log panels with context type third_party_risk.

        Returns:
            list: log panel changes with context type third_party_risk, or [] if not found
        """
        warnings.warn(DEPRECATION_MSG, DeprecationWarning)
        return list(
            filter(
                lambda log: log.get('context', {}).get('type') == 'third_party_risk',
                self.log_context_changes,
            ),
        )

    @property
    def log_tpr_assessment_changes(self) -> list:
        """Third Party Risk: Filter for log panels for tpr_assessment_change.

        Returns:
            list: log panel changes with context type third party risk containing only
                  tpr_assessment_changes, or [] if not found
        """
        warnings.warn(DEPRECATION_MSG, DeprecationWarning)
        return self._get_specific_context_changes('third_party_risk', 'tpr_assessment_change')
